This formats with colours the results from a fuzz run and prints them to
the terminal.
Usage
# S3 method for cbtf
print(x, show_all = FALSE, ...)
Value
No return value, called for side effects.
Arguments
x
An object of class cbtf.
show_all
Whether all results should be printed. By default (FALSE),
only the functions that reported an error or a warning are printed.
If TRUE, all functions tested are printed, including those that
were successful or were skipped.
...
Further arguments passed to or from other methods.
These are currently ignored.